<?php

namespace Drupal\Tests\widget_type\Kernel;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Link;
use Drupal\Core\Routing\RedirectDestinationInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\widget_type\Entity\WidgetType;
use Drupal\widget_type\WidgetTypeListBuilder;

/**
 * Kernel tests for WidgetTypeListBuilder.
 *
 * @group widget_type
 * @coversDefaultClass \Drupal\widget_type\WidgetTypeListBuilder
 */
class WidgetTypeListBuilderTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'widget_type',
    'field',
    'text',
    'user',
    'system',
  ];

  /**
   * The system under test.
   *
   * @var \Drupal\widget_type\WidgetTypeListBuilder
   */
  private $theSut;

  /**
   * The entity.
   *
   * @var \Drupal\widget_type\WidgetTypeInterface
   */
  private $entity;

  /**
   * {@inheritdoc}
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  protected function setUp() {
    parent::setUp();
    \Drupal::setContainer($this->container);
    $this->installEntitySchema('widget_type');
    $this->installEntitySchema('user');
    $this->installConfig(['field', 'widget_type', 'user']);
    $this->theSut = new WidgetTypeListBuilder(
      $this->prophesize(EntityTypeInterface::class)->reveal(),
      $this->prophesize(EntityStorageInterface::class)->reveal(),
      $this->prophesize(DateFormatterInterface::class)->reveal(),
      $this->prophesize(RedirectDestinationInterface::class)->reveal()
    );
    $this->entity = WidgetType::create([
      'name' => 'The name',
      'remote_widget_id' => 'remote-id',
      'remote_widget_version' => 'v1.2.3',
      'remote_widget_directory' => 'https://the-s3/path',
    ]);
    $this->entity->save();
  }

  /**
   * @covers ::buildRow
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function testBuildRow() {
    $row = $this->theSut->buildRow($this->entity);
    $this->assertInstanceOf(Link::class, $row['title']);
    $this->assertSame('operations', $row['operations']['data']['#type']);
    $this->assertArraySubset([
      'status' => 'Enabled',
      'changed' => NULL,
      'directory' => 'https://the-s3/path',
      'version' => 'v1.2.3',
    ], $row);
  }

  /**
   * @covers ::buildHeader
   */
  public function testBuildHeader() {
    $this->assertEquals([
      'title' => 'Title',
      'status' => 'Status',
      'changed' => 'Updated',
      'directory' => 'Directory',
      'version' => 'Version',
      'operations' => 'Operations',
    ], $this->theSut->buildHeader());
  }

  /**
   * @covers ::getDefaultOperations
   */
  public function testGetDefaultOperations() {
    $operations = $this->theSut->getOperations($this->entity);
    $this->assertEquals([], $operations);
  }

}
